# -*- coding: utf-8 -*-

import datetime

from django.db.models import Q

from gisdo.utils import DateMixin
from kinder.core.direct.models import DRS
from kinder.core.group.enum import GroupStatusEnum
from kinder.core.group.models import Pupil


def get_193_filter(**kwargs):
    """Фильтр для показателя 19.3
    - направния в статусе "Направлен в ДОУ", "Заключение договора"
    """

    return Q(
        Q(group__unit_id=kwargs.get("unit").id) & ~Q(
            group__status=GroupStatusEnum.ARCHIVE) &
        Q(status__code__in=(DRS.REGISTER, DRS.DOGOVOR))
    )


def get_34_filter(**kwargs):
    """Фильтр для показателя 34
    - направления в статусе "Направлен в ДОУ", "Заключение договора", "зачислен"
    - дата создания направления: [01.01.2015 - текущая дата],
    т.е текущий календарный год
    """
    today_ = datetime.date.today()
    return Q(status__code__in=[DRS.ACCEPT, DRS.DOGOVOR, DRS.REGISTER],
             date__range=(datetime.date(today_.year, 1, 1), today_))


def get_291_filter(**kwargs):
    """Фильтр для показателя 29.1
    - направления в статусе ""Направлен в ДОУ, "Заключение договора"
    (в плановую и фактическую группу)
    - в то доу который зачислен (есть зачисление сейчас)
    - желаемая дата зачисления <=01.09.2015 и без желаемой даты зачисления
    (смена года)
    - Если Дата рождения ребенка позже либо равна 01.09 текущего учебного года
    (сейчас - 01.09.2015), то заявки таких детей исключаем из показателя
    """

    current_learn_year_begin = DateMixin._get_current_calendar_year()

    return Q(
        status__code__in=(DRS.REGISTER, DRS.DOGOVOR),
        group__status__in=(GroupStatusEnum.FACT, GroupStatusEnum.PLAN)
    ) & Q(
        Q(declaration__desired_date__lte=current_learn_year_begin) |
        Q(declaration__desired_date__isnull=True)
    ) & ~Q(
        declaration__children__date_of_birth__gte=current_learn_year_begin
    )
